Command Line Interface (CLI)
=============================

The CLI allows for initialization of a Python environment
(:code:`virtue env install`) and inspection
of the Virtue packages in an active Python environment
(:code:`virtue env info`, :code:`virtue env list`).

See the cli help (:code:`virtue --help`) or the
:ref:`Command Line Interface (CLI) Reference` for more details
on the interface.
